"""Forms for the rbmotd extension."""

from __future__ import unicode_literals

import hashlib

from django import forms
from django.utils.translation import ugettext as _
from djblets.extensions.forms import SettingsForm


class MotdSettingsForm(SettingsForm):
    """The settings form for the motd extension."""

    enabled = forms.BooleanField(initial=False, required=False)
    message = forms.CharField(
        max_length=512,
        required=False,
        help_text=_('This field expects valid HTML. Entities must be '
                    'properly escaped.'),
        widget=forms.TextInput(attrs={
            'size': 100,
        }))

    def set_key_value(self, key, value):
        """Set the given value in the extension settings.

        This overrides the base settings form method so that when the
        ``message`` key is set, it will additionally compute and store a
        ``message_id`` key.

        Args:
            key (unicode):
                The key to set.

            value (object):
                The value to set.
        """
        if key == 'message':
            message_id = hashlib.sha256(value).hexdigest()
            self.set_key_value('message_id', message_id)

        super(MotdSettingsForm, self).set_key_value(key, value)



"""Admin site URL definitions for the rbmotd extension."""

from __future__ import unicode_literals

from django.conf.urls import url
from reviewboard.extensions.views import configure_extension

from rbmotd.extension import MotdExtension
from rbmotd.forms import MotdSettingsForm


urlpatterns = [
    url(r'^$', configure_extension, {
         'ext_class': MotdExtension,
         'form_class': MotdSettingsForm,
     }),
]



#!/usr/bin/env python

from reviewboard.extensions.packaging import setup

from rbmotd import get_package_version


PACKAGE = 'rbmotd'

setup(
    name=PACKAGE,
    version=get_package_version(),
    description='Message of the Day support for Review Board',
    url='https://www.reviewboard.org/',
    author='Beanbag, Inc.',
    author_email='support@beanbaginc.com',
    maintainer='Beanbag, Inc.',
    maintainer_email='support@beanbaginc.com',
    packages=['rbmotd'],
    entry_points={
        'reviewboard.extensions': [
            'rbmotd = rbmotd.extension:MotdExtension',
        ],
    },
    package_data={
        'rbmotd': [
            'templates/rbmotd/*.html',
        ]
    },
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Review Board',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ]
)



"""Message of the day extension for Review Board."""

from __future__ import unicode_literals

from reviewboard.extensions.base import Extension
from reviewboard.extensions.hooks import TemplateHook


class MotdTemplateHook(TemplateHook):
    """Template hook to inject the motd."""

    def __init__(self, extension):
        """Initialize the hook.

        Args:
            extension (MotdExtension):
                The extension that owns the hook.
        """
        super(MotdTemplateHook, self).__init__(extension, 'base-after-navbar',
                                               'rbmotd/motd.html')

    def render_to_string(self, request, context):
        """Render the data for the hook location.

        Args:
            request (django.http.HttpRequest):
                The request object.

            context (dict):
                The template render context.

        Returns:
            django.utils.safestring.SafeText:
            The rendered HTML.
        """
        ext_settings = self.extension.settings

        context.update({
            'motd_close_value': '%s-closed' % ext_settings['message_id'],
            'motd_cookie': 'rbmotd',
            'motd_enabled': ext_settings.get('enabled'),
            'motd_message': ext_settings.get('message'),
        })

        return super(MotdTemplateHook, self).render_to_string(request, context)


class MotdExtension(Extension):
    """Extends Review Board to display a Message of the Day.

    This allows an administrator to set announcement text that will appear at
    the top of every page. This can be used for important announcements,
    status updates, downtime notices, or anything else.
    """
    metadata = {
        'Name': 'Message of the Day',
        'Summary': (
            'Displays a configurable, dismissable announcement or message '
            'that will be shown to all Review Board users.'
        ),
    }

    css_bundles = {
        'default': {
            'source_filenames': ['css/motd.less'],
        }
    }

    default_settings = {
        'enabled': False,
        'message': '',
        'message_id': '',
    }

    is_configurable = True

    def initialize(self):
        """Initialize the extension."""
        MotdTemplateHook(self)
